@@ -12,24 +12,41 @@ import random
 import uuid
 from typing import Any
 from typing import BinaryIO
+from typing import Final
 from typing import Optional
 from typing import Tuple
 from typing import TypeVar
 from typing import Union
 from urllib.parse import parse_qs
+from urllib.parse import urlencode
 from urllib.parse import urlparse
 
 import aiohttp
 import arrow
 
-from . import __display_name__
 from . import USER_AGENT
+from . import __display_name__
 
 logger = logging.getLogger(__display_name__)
 
 
 ActivityPubClass = TypeVar("ActivityPubClass", bound="ActivityPub")
-REDIRECT_URI = "urn:ietf:wg:oauth:2.0:oob"
+REDIRECT_URI: Final[str] = "urn:ietf:wg:oauth:2.0:oob"
+
+# HTTP status codes of interest (more detail at https://en.wikipedia.org/wiki/List_of_HTTP_status_codes)
+STATUS_BAD_REQUEST: Final[int] = 400
+STATUS_UNAUTHORIZED: Final[int] = 401
+STATUS_FORBIDDEN: Final[int] = 403
+STATUS_NOT_FOUND: Final[int] = 404
+STATUS_CONFLICT: Final[int] = 409
+STATUS_GONE: Final[int] = 410
+STATUS_UNPROCESSABLE_ENTITY: Final[int] = 422
+STATUS_TOO_MANY_REQUESTS: Final[int] = 429
+STATUS_INTERNAL_SERVER_ERROR: Final[int] = 500
+
+INSTANCE_TYPE_MASTODON: Final[str] = "Mastodon"
+INSTANCE_TYPE_PLEROMA: Final[str] = "Pleroma"
+INSTANCE_TYPE_TAKAHE: Final[str] = "takahe"
 
 
 class ActivityPub:
@@ -39,16 +56,13 @@ class ActivityPub:
     for the function of MastodonAmnesia
     """
 
-    # It's not that many over. It's using 9 instance attributes (opposed to 7 being
-    # deemed the max attributes a class should have)
-    # pylint: disable-msg=too-many-instance-attributes
-
     def __init__(
         self: ActivityPubClass,
         instance: str,
         session: aiohttp.ClientSession,
         access_token: str,
     ) -> None:
+        """Initialise ActivityPub instance with reasonable default values."""
         self.instance = instance
         self.authorization = f"Bearer {access_token}"
         self.session = session
@@ -56,13 +70,13 @@ class ActivityPub:
             "next": {"max_id": None, "min_id": None},
             "prev": {"max_id": None, "min_id": None},
         }
-        self.is_instance_pleroma = False
+        self.instance_type = INSTANCE_TYPE_MASTODON  # default until determined otherwise with determine_instance_type()
         self.ratelimit_limit = 300
         self.ratelimit_remaining = 300
         self.ratelimit_reset = arrow.now()
 
     async def verify_credentials(self: ActivityPubClass) -> Any:
-        """It verifies the credentials of the user.
+        """Verify the credentials of the user.
 
         :param self: ActivityPubClass
         :type self: ActivityPubClass
@@ -87,7 +101,7 @@ class ActivityPub:
         return json_response
 
     async def determine_instance_type(self: ActivityPubClass) -> None:
-        """It checks if the instance is a Pleroma instance or not.
+        """Check if the instance is a Pleroma instance or not.
 
         :param self: The class itself
         :type self: ActivityPubClass
@@ -100,8 +114,10 @@ class ActivityPub:
             await ActivityPub.__check_exception(response=response)
             response_dict = await response.json()
         self.instance = instance
-        if "Pleroma" in response_dict["version"]:
-            self.is_instance_pleroma = True
+        if INSTANCE_TYPE_TAKAHE in response_dict.get("version"):
+            self.instance_type = INSTANCE_TYPE_TAKAHE
+        elif INSTANCE_TYPE_PLEROMA in response_dict.get("version"):
+            self.instance_type = INSTANCE_TYPE_PLEROMA
         logger.debug(
             "ActivityPub.determine_instance_type -> response.dict:\n%s",
             json.dumps(response_dict, indent=4),
@@ -113,7 +129,7 @@ class ActivityPub:
         max_id: Optional[str] = None,
         min_id: Optional[str] = None,
     ) -> Any:
-        """It gets the statuses of a given account.
+        """Get statuses of a given account.
 
         :param self: The class instance
         :type self: ActivityPubClass
@@ -125,7 +141,6 @@ class ActivityPub:
         :type min_id: Optional[str]
         :return: A list of statuses.
         """
-
         logger.debug(
             "ActivityPub.get_account_statuses(account_id=%s, max_id=%s, min_id=%s)",
             account_id,
@@ -163,7 +178,7 @@ class ActivityPub:
         self: ActivityPubClass,
         status: Union[str, dict[Any, Any]],
     ) -> Any:
-        """It deletes a status.
+        """Delete a status.
 
         :param self: The class that inherits from ActivityPub
         :type self: ActivityPubClass
@@ -172,7 +187,6 @@ class ActivityPub:
         :type status: str or dict
         :return: The response from the server.
         """
-
         # add random delay of up to 3 seconds in case we are deleting many
         # statuses in a batch
         sleep_for = random.SystemRandom().random() * 3
@@ -187,10 +201,10 @@ class ActivityPub:
             status_id = status
         elif isinstance(status, dict):
             status_id = status["id"]
-            if self.is_instance_pleroma and status["reblogged"]:
+            if self.instance_type == INSTANCE_TYPE_PLEROMA and status["reblogged"]:
                 response = await self.undo_reblog(status=status)
                 return response
-            if self.is_instance_pleroma and status["favourited"]:
+            if self.instance_type == INSTANCE_TYPE_PLEROMA and status["favourited"]:
                 response = await self.undo_favourite(status=status)
                 return response
 
@@ -213,7 +227,7 @@ class ActivityPub:
     async def undo_reblog(
         self: ActivityPubClass, status: Union[str, dict[Any, Any]]
     ) -> Any:
-        """Removes a reblog.
+        """Remove a reblog.
 
         :param self: The class that inherits from ActivityPub
         :type self: ActivityPubClass
@@ -251,7 +265,7 @@ class ActivityPub:
         self: ActivityPubClass,
         status: Union[str, dict[Any, Any]],
     ) -> Any:
-        """Removes a favourite.
+        """Remove a favourite.
 
         :param self: The class that inherits from ActivityPub
         :type self: ActivityPubClass
@@ -286,7 +300,106 @@ class ActivityPub:
         return result
 
     @staticmethod
-    async def get_auth_token(
+    async def generate_authorization_url(
+        instance_url: str,
+        client_id: str,
+        user_agent: str = USER_AGENT,
+    ):
+        """Create URL to get access token interactively from website.
+
+        :param instance_url: The URL of the Mastodon instance you want to connect to
+        :type instance_url: str
+        :param client_id: Client id of app as generated by create_app method
+        :type client_id: str
+        :param user_agent: User agent identifier to use. Defaults to
+        minimal_activitypub related one.
+        :type user_agent: str
+        :param client_website: Link to site for user_agent. Defaults to link to
+        minimal_activitypub on Pypi.org
+        :return: String containing URL to visit to get access token interactively from instance.
+        """
+        logger.debug(
+            "ActivityPub.get_auth_token_interactive(instance_url=%s, session=...,client_id=%s, user_agent=%s)",
+            instance_url,
+            client_id,
+            user_agent,
+        )
+        if "http" not in instance_url:
+            instance_url = f"https://{instance_url}"
+
+        url_params = urlencode(
+            {
+                "response_type": "code",
+                "client_id": client_id,
+                "redirect_uri": REDIRECT_URI,
+                "scope": "read write",
+            }
+        )
+        auth_url = f"{instance_url}/oauth/authorize?{url_params}"
+        logger.debug(
+            "ActivityPub.get_auth_token_interactive(...) -> %s",
+            auth_url,
+        )
+
+        return auth_url
+
+    @staticmethod
+    async def validate_authorization_code(
+        session: aiohttp.ClientSession,
+        instance_url: str,
+        authorization_code: str,
+        client_id: str,
+        client_secret: str,
+    ) -> str:
+        """Validate an authorization code and get access token needed for API access.
+
+        :param session: aiohttp.ClientSession
+        :type session: aiohttp.ClientSession
+        :param instance_url: The URL of the Mastodon instance you want to connect to
+        :type instance_url: str
+        :param authorization_code: authorization code
+        :param type: str
+        :param client_id: client id as returned by create_app method
+        :param type: str
+        :param client_secret: client secret as returned by create_app method
+        :param type: str
+
+        :return: access token
+        """
+        logger.debug(
+            "ActivityPub.validate_authorization_code(authorization_code=%s, client_id=%s, client_secret=<redacted>)",
+            authorization_code,
+            client_id,
+        )
+        if "http" not in instance_url:
+            instance_url = f"https://{instance_url}"
+
+        form_data = aiohttp.FormData()
+        form_data.add_field("client_id", client_id)
+        form_data.add_field("client_secret", client_secret)
+        form_data.add_field("scope", "read write")
+        form_data.add_field("redirect_uri", REDIRECT_URI)
+        form_data.add_field("grant_type", "authorization_code")
+        form_data.add_field("code", authorization_code)
+        async with session.post(
+            url=f"{instance_url}/oauth/token",
+            data=form_data,
+        ) as response:
+            logger.debug(
+                "ActivityPub.validate_authorization_code - response:\n%s",
+                response,
+            )
+            await ActivityPub.__check_exception(response)
+            response_dict = await response.json()
+
+        logger.debug(
+            "ActivityPub.validate_authorization_code - response.json: \n%s",
+            json.dumps(response_dict, indent=4),
+        )
+        return str(response_dict["access_token"])
+
+    @staticmethod
+    async def get_auth_token(  # noqa: PLR0913  - No way around needing all this parameters
         instance_url: str,
         username: str,
         password: str,
@@ -294,7 +407,7 @@ class ActivityPub:
         user_agent: str = USER_AGENT,
         client_website: str = "https://pypi.org/project/minimal-activitypub/",
     ) -> str:
-        """It creates an app, then uses that app to get an access token.
+        """Create an app and use it to get an access token.
 
         :param instance_url: The URL of the Mastodon instance you want to connect to
         :type instance_url: str
@@ -311,10 +424,75 @@ class ActivityPub:
         minimal_activitypub on Pypi.org
         :return: The access token is being returned.
         """
+        logger.debug(
+            "ActivityPub.get_auth_token(instance_url=%s, username=%s, password=<redacted>, session=..., "
+            "user_agent=%s, client_website=%s)",
+            instance_url,
+            username,
+            user_agent,
+            client_website,
+        )
+        if "http" not in instance_url:
+            instance_url = f"https://{instance_url}"
 
-        # Two of the arguements have sensible default values so only 4 are really
-        # necessary.
-        # pylint: disable-msg=too-many-arguments
+        client_id, client_secret = await ActivityPub.create_app(
+            client_website=client_website,
+            instance_url=instance_url,
+            session=session,
+            user_agent=user_agent,
+        )
+
+        form_data = aiohttp.FormData()
+        form_data.add_field("client_id", client_id)
+        form_data.add_field("client_secret", client_secret)
+        form_data.add_field("scope", "read write")
+        form_data.add_field("redirect_uris", REDIRECT_URI)
+        form_data.add_field("grant_type", "password")
+        form_data.add_field("username", username)
+        form_data.add_field("password", password)
+        async with session.post(
+            url=f"{instance_url}/oauth/token",
+            data=form_data,
+        ) as response:
+            logger.debug(
+                "ActivityPub.get_auth_token - response:\n%s",
+                response,
+            )
+            await ActivityPub.__check_exception(response)
+            response_dict = await response.json()
+
+        logger.debug(
+            "ActivityPub.get_auth_token - response.json: \n%s",
+            json.dumps(response_dict, indent=4),
+        )
+        return str(response_dict["access_token"])
+
+    @staticmethod
+    async def create_app(
+        instance_url: str,
+        session: aiohttp.ClientSession,
+        user_agent: str = USER_AGENT,
+        client_website: str = "https://pypi.org/project/minimal-activitypub/",
+    ) -> Tuple[str, str]:
+        """Create an app.
+
+        :param instance_url: The URL of the Mastodon instance you want to connect to
+        :type instance_url: str
+        :param session: aiohttp.ClientSession
+        :type session: aiohttp.ClientSession
+        :param user_agent: User agent identifier to use. Defaults to
+        minimal_activitypub related one.
+        :type user_agent: str
+        :param client_website: Link to site for user_agent. Defaults to link to
+        minimal_activitypub on Pypi.org
+        :return: tuple(client_id, client_secret)
+        """
+        logger.debug(
+            "ActivityPub.create_app(instance_url=%s, session=..., user_agent=%s, client_website=%s)",
+            instance_url,
+            user_agent,
+            client_website,
+        )
 
         if "http" not in instance_url:
             instance_url = f"https://{instance_url}"
@@ -329,45 +507,18 @@ class ActivityPub:
             data=form_data,
         ) as response:
             logger.debug(
-                "ActivityPub.get_auth_token apps response: \n%s",
+                "ActivityPub.create_app response: \n%s",
                 response,
             )
             await ActivityPub.__check_exception(response)
             response_dict = await response.json()
-
         logger.debug(
-            "ActivityPub.get_auth_token apps response.json: \n%s",
+            "ActivityPub.create_app response.json: \n%s",
             json.dumps(response_dict, indent=4),
         )
+        return (response_dict["client_id"]), (response_dict["client_secret"])
 
-        client_id = response_dict["client_id"]
-        client_secret = response_dict["client_secret"]
-        form_data = aiohttp.FormData()
-        form_data.add_field("client_id", client_id)
-        form_data.add_field("client_secret", client_secret)
-        form_data.add_field("scope", "read write")
-        form_data.add_field("redirect_uris", REDIRECT_URI)
-        form_data.add_field("grant_type", "password")
-        form_data.add_field("username", username)
-        form_data.add_field("password", password)
-        async with session.post(
-            url=f"{instance_url}/oauth/token",
-            data=form_data,
-        ) as response:
-            logger.debug(
-                "ActivityPub.get_auth_token token response: \n%s",
-                response,
-            )
-            await ActivityPub.__check_exception(response)
-            response_dict = await response.json()
-
-        logger.debug(
-            "ActivityPub.get_auth_token apps response.json: \n%s",
-            json.dumps(response_dict, indent=4),
-        )
-        return str(response_dict["access_token"])
-
-    async def post_status(
+    async def post_status(  # noqa: PLR0913  - No way around needing all this parameters
         self: ActivityPubClass,
         status: str,
         visibility: str = "public",
@@ -375,7 +526,7 @@ class ActivityPub:
         sensitive: bool = False,
         spoiler_text: Optional[str] = None,
     ) -> Any:
-        """Posts a status to the fediverse.
+        """Post a status to the fediverse.
 
         :param status: The text to be posted on the timeline.
         :param visibility: Visibility of the posted status. Enumerable one of `public`,
@@ -389,8 +540,6 @@ class ActivityPub:
         content. Statuses are generally collapsed behind this field. Defaults to `None`
         :return: Dict of the status just posted.
         """
-        # pylint: disable=too-many-arguments
-
         logger.debug(
             "ActivityPub.post_status(status=%s, visibility=%s, media_ids=%s, sensitive=%s, spoiler_text=%s)",
             status,
@@ -401,30 +550,58 @@ class ActivityPub:
         )
         await self.__pre_call_checks()
 
+        url = f"{self.instance}/api/v1/statuses"
         headers = {
             "Authorization": self.authorization,
             "Idempotency-Key": uuid.uuid4().hex,
         }
-        url = f"{self.instance}/api/v1/statuses/"
-        data = aiohttp.FormData()
-        data.add_field("status", status)
-        data.add_field("visibility", visibility)
-        data.add_field("sensitive", sensitive)
-        if media_ids:
-            data.add_field("media_ids[]", media_ids)
-        if spoiler_text:
-            data.add_field("spoiler_text", spoiler_text)
 
-        logger.debug("ActivityPub.post_status - posting data=%s", data)
-        async with self.session.post(
-            url=url,
-            headers=headers,
-            data=data,
-        ) as response:
+        if self.instance_type == INSTANCE_TYPE_TAKAHE:
+            json_data = {
+                "status": status,
+                "visibility": visibility,
+                "sensitive": sensitive,
+            }
+            if media_ids:
+                json_data["media_ids"] = media_ids
+            if spoiler_text:
+                json_data["spoiler_text"] = spoiler_text
 
-            self.__update_ratelimit(headers=response.headers)
-            await ActivityPub.__check_exception(response=response)
-            result = await response.json()
+            async with self.session.post(
+                url=url,
+                headers=headers,
+                json=json_data,
+            ) as response:
+                self.__update_ratelimit(headers=response.headers)
+                await ActivityPub.__check_exception(response=response)
+                result = await response.json()
+                logger.debug(
+                    "ActivityPub.post_status - request_info:\n%s",
+                    response.request_info,
+                )
+
+        else:
+            form_data = aiohttp.FormData()
+            form_data.add_field(name="status", value=status)
+            form_data.add_field(name="visibility", value=visibility)
+            form_data.add_field(name="sensitive", value=sensitive)
+            if media_ids:
+                form_data.add_field(name="media_ids[]", value=media_ids)
+            if spoiler_text:
+                form_data.add_field(name="spoiler_text", value=spoiler_text)
+
+            async with self.session.post(
+                url=url,
+                headers=headers,
+                data=form_data,
+            ) as response:
+                self.__update_ratelimit(headers=response.headers)
+                await ActivityPub.__check_exception(response=response)
+                result = await response.json()
+                logger.debug(
+                    "ActivityPub.post_status - request_info:\n%s",
+                    response.request_info,
+                )
 
         logger.debug(
             "ActivityPub.post_status -> result:\n%s",
@@ -439,7 +616,7 @@ class ActivityPub:
         description: Optional[str] = None,
         focus: Optional[Tuple[float, float]] = None,
     ) -> Any:
-        """Post a media file (image or video)
+        """Post a media file (image or video).
 
         :param file: The file to be uploaded
         :param mime_type: Mime type
@@ -448,7 +625,6 @@ class ActivityPub:
         (see “Focal points <https://docs.joinmastodon.org/methods/statuses/media/#focal-points>”_)
         :return: Dict containing details for this media on server, such a `id`, `url` etc
         """
-
         logger.debug(
             "ActivityPub.post_media(file=..., mime_type=%s, description=%s, focus=%s)",
             mime_type,
@@ -475,7 +651,7 @@ class ActivityPub:
         )
         if description:
             data.add_field(name="description", value=description)
-        if focus and len(focus) >= 2:
+        if focus and len(focus) >= 2:  # noqa: PLR2004
             data.add_field(name="focus", value=f"{focus[0]},{focus[1]}")
 
         async with self.session.post(
@@ -483,7 +659,6 @@ class ActivityPub:
             headers=headers,
             data=data,
         ) as response:
-
             self.__update_ratelimit(headers=response.headers)
             await ActivityPub.__check_exception(response=response)
             result = await response.json()
@@ -495,7 +670,7 @@ class ActivityPub:
         return result
 
     async def __pre_call_checks(self: ActivityPubClass) -> None:
-        """Checks to perform before contacting the instance server.
+        """Do checks contacting the instance server.
 
         For now just looking at rate limits by checking if the rate
         limit is 0 and the rate limit reset time is in the future, raise
@@ -512,9 +687,8 @@ class ActivityPub:
             raise RatelimitError(429, None, "Rate limited")
 
     def __parse_next_prev(self: ActivityPubClass, links: Optional[str]) -> None:
-        """It takes a string of the form `https://example.com/api/v1/timelines/
-        home?min_id=12345&max_id=67890` and extracts the values of `min_id` and
-        `max_id` from it and stores them in the instance attributes
+        """Extract min_id and max_id from a string like `https://example.com/api/v1/timelines/
+        home?min_id=12345&max_id=67890` and store them in the instance attributes
         pagination_min_id and pagination_max_id.
 
         :param self: The class that is being parsed
@@ -571,7 +745,7 @@ class ActivityPub:
         :type headers: Any
         """
         temp_ratelimit_limit = temp_ratelimit_remaining = temp_ratelimit_reset = None
-        if not self.is_instance_pleroma:
+        if not self.instance_type == INSTANCE_TYPE_PLEROMA:
             temp_ratelimit_limit = headers.get("X-RateLimit-Limit")
             temp_ratelimit_remaining = headers.get("X-RateLimit-Remaining")
             temp_ratelimit_reset = headers.get("X-RateLimit-Reset")
@@ -587,7 +761,7 @@ class ActivityPub:
             "ActivityPub.__update_ratelimit "
             "- Pleroma Instance: %s "
             "- RateLimit Limit %s",
-            self.is_instance_pleroma,
+            self.instance_type == INSTANCE_TYPE_PLEROMA,
             self.ratelimit_limit,
         )
         logger.debug(
@@ -612,25 +786,24 @@ class ActivityPub:
         logger.debug(
             "ActivityPub.__check_exception - response.status = %s", response.status
         )
-        if response.status >= 400:
-
+        if response.status >= STATUS_BAD_REQUEST:
             error_message = await ActivityPub.__determine_error_message(response)
 
-            if response.status == 401:
+            if response.status == STATUS_UNAUTHORIZED:
                 raise UnauthorizedError(response.status, response.reason, error_message)
-            if response.status == 403:
+            if response.status == STATUS_FORBIDDEN:
                 raise ForbiddenError(response.status, response.reason, error_message)
-            if response.status == 404:
+            if response.status == STATUS_NOT_FOUND:
                 raise NotFoundError(response.status, response.reason, error_message)
-            if response.status == 409:
+            if response.status == STATUS_CONFLICT:
                 raise ConflictError(response.status, response.reason, error_message)
-            if response.status == 410:
+            if response.status == STATUS_GONE:
                 raise GoneError(response.status, response.reason, error_message)
-            if response.status == 422:
+            if response.status == STATUS_UNPROCESSABLE_ENTITY:
                 raise UnprocessedError(response.status, response.reason, error_message)
-            if response.status == 429:
+            if response.status == STATUS_TOO_MANY_REQUESTS:
                 raise RatelimitError(response.status, response.reason, error_message)
-            if response.status < 500:
+            if response.status < STATUS_INTERNAL_SERVER_ERROR:
                 raise ClientError(response.status, response.reason, error_message)
 
             raise ServerError(response.status, response.reason, error_message)
@@ -644,7 +817,6 @@ class ActivityPub:
         :type response: aiohttp.ClientResponse
         :return: The error message is being returned.
         """
-
         error_message = "Exception has occurred"
         try:
             content = await response.json()
@@ -652,8 +824,11 @@ class ActivityPub:
         except (aiohttp.ClientError, KeyError):
             try:
                 error_message = await response.text()
-            except (aiohttp.ClientError, LookupError):
-                pass
+            except (aiohttp.ClientError, LookupError) as lookup_error:
+                logger.debug(
+                    "ActivityPub.__determine_error_message - Error when determining response.text  = %s",
+                    lookup_error,
+                )
         logger.debug(
             "ActivityPub.__determine_error_message - error_message = %s", error_message
         )
@@ -666,21 +841,24 @@ class ActivityPubError(Exception):
 
 class NetworkError(ActivityPubError):
     """`NetworkError` is a subclass of `ActivityPubError` that is raised when
-    there is a network error."""
+    there is a network error.
+    """
 
     pass
 
 
 class ApiError(ActivityPubError):
     """`ApiError` is a subclass of `ActivityPubError` that is raised when there
-    is an API error."""
+    is an API error.
+    """
 
     pass
 
 
 class ClientError(ActivityPubError):
     """`ClientError` is a subclass of `ActivityPubError` that is raised when
-    there is a client error."""
+    there is a client error.
+    """
 
     pass
 
@@ -688,7 +866,8 @@ class ClientError(ActivityPubError):
 class UnauthorizedError(ClientError):
     """`UnauthorizedError` is a subclass of `ClientError` that is raised when
     the user represented by the auth_token is not authorized to perform a
-    certain action."""
+    certain action.
+    """
 
     pass
 
@@ -696,48 +875,55 @@ class UnauthorizedError(ClientError):
 class ForbiddenError(ClientError):
     """`ForbiddenError` is a subclass of `ClientError` that is raised when the
     user represented by the auth_token is forbidden to perform a certain
-    action."""
+    action.
+    """
 
     pass
 
 
 class NotFoundError(ClientError):
     """`NotFoundError` is a subclass of `ClientError` that is raised when an
-    object for an action cannot be found."""
+    object for an action cannot be found.
+    """
 
     pass
 
 
 class ConflictError(ClientError):
     """`ConflictError` is a subclass of `ClientError` that is raised when there
-    is a conflict with performing an action."""
+    is a conflict with performing an action.
+    """
 
     pass
 
 
 class GoneError(ClientError):
     """`GoneError` is a subclass of `ClientError` that is raised when an object
-    for an action has gone / been deleted."""
+    for an action has gone / been deleted.
+    """
 
     pass
 
 
 class UnprocessedError(ClientError):
     """`UnprocessedError` is a subclass of `ClientError` that is raised when an
-    action cannot be processed."""
+    action cannot be processed.
+    """
 
     pass
 
 
 class RatelimitError(ClientError):
     """`RatelimitError` is a subclass of `ClientError` that is raised when
-    we've reached a limit of number of actions performed quickly."""
+    we've reached a limit of number of actions performed quickly.
+    """
 
     pass
 
 
 class ServerError(ActivityPubError):
     """`ServerError` is a subclass of `ActivityPubError` that is raised when
-    the server / instance encountered an error."""
+    the server / instance encountered an error.
+    """
 
     pass
